from distutils.core import setup

setup(
                name = 'fortest',
                version = '1.6.0',
                py_modules = ['fortest'],
                author = 'xinxin',
                author_email = '251089003@qq.com',
                url = 'http://www.baidu.com',
                description = 'a for test tab complete',
        )



import sys
""" this is an area for list """
def print_lol(the_list,indent=False,level=0,fn=sys.stdout):
        for each_item in the_list:
                if isinstance(each_item,list):
                        print_lol(each_item,indent,level+1,fn)
                else:
                        if indent:
                                for tab_stop in range(level):
                                        print("\t",end='',file=fn)
                        print(each_item,file=fn)
